armadillo4r-package: An 'Armadillo' Interface

armadillo4r-packageR Documentation

An 'Armadillo' Interface

Description

Provides function declarations and inline function definitions that facilitate communication between R and the 'Armadillo' 'C++' library for linear algebra and scientific computing. This implementation is derived from Vargas Sepulveda and Schneider Malamud (2024) <doi:10.1016/j.softx.2025.102087>.


armadillo4r documentation built on Aug. 23, 2026, 5:07 p.m.