armadillo_version: Get Armadillo version

View source: R/version.R

armadillo_versionR Documentation

Get Armadillo version

Description

Provides the Armadillo C++ library version name and number included in the package.

Usage

armadillo_version()

Value

A string with the Armadillo version name and number

Examples

armadillo_version()

armadillo4r documentation built on June 12, 2026, 5:06 p.m.