| armadillo4r-package | R Documentation |
Provides function declarations and inline function definitions that facilitate communication between R and the 'Armadillo' 'C++' library for linear algebra and scientific computing. This implementation is derived from Vargas Sepulveda and Schneider Malamud (2024) <doi:10.1016/j.softx.2025.102087>.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.