Learn R Programming

armadillo4r (version 0.7.0)

armadillo4r-package: armadillo4r: An 'Armadillo' Interface

Description

Provides function declarations and inline function definitions that facilitate communication between R and the 'Armadillo' 'C++' library for linear algebra and scientific computing. This implementation is derived from Vargas Sepulveda and Schneider Malamud (2024) tools:::Rd_expr_doi("10.1016/j.softx.2025.102087").

Arguments

Author

Maintainer: Mauricio Vargas Sepulveda m.vargas.sepulveda@gmail.com (ORCID)

Authors:

  • Conrad Sanderson (Armadillo library (C++))

Other contributors:

  • Jonathan Schneider Malamud [contributor]

See Also